@@ -923,3 +923,208 @@ class TestHyperparameterOptimization(object):
                         assert instance.hyperparameter_optimization.call_count == 1
 
         assert result.exit_code == 0
+
+
+class TestLightningDeploy(object):
+    def test_lightning_deploy_hugging_face_happy_case(self):
+        extra_args = """
+                {
+                    "transformers_version": "4.6.1",
+                    "pytorch_version": "1.7.1"
+                }
+                """
+
+        runner = CliRunner()
+
+        with patch(
+                'sagify.commands.initialize._get_local_aws_profiles',
+                return_value=['default', 'sagify']
+        ):
+            with patch(
+                    'sagify.sagemaker.sagemaker.SageMakerClient'
+            ) as mocked_sage_maker_client:
+                instance = mocked_sage_maker_client.return_value
+                with runner.isolated_filesystem():
+                    with open('extra_config_file.json', 'w') as f:
+                        f.write(extra_args)
+
+                    result = runner.invoke(
+                        cli=cli,
+                        args=[
+                            'cloud', 'lightning-deploy',
+                            '--framework', 'huggingface',
+                            '-m', 's3://bucket/model/location/model.tar.gz',
+                            '-n', '2',
+                            '-e', 'ml.c4.2xlarge',
+                            '--extra-config-file', 'extra_config_file.json',
+                            '--aws-region', 'us-east-1',
+                            '--aws-profile', 'sagify'
+                        ]
+                    )
+
+                    assert instance.deploy_hugging_face.call_count == 1
+                    instance.deploy_hugging_face.assert_called_with(
+                        s3_model_location='s3://bucket/model/location/model.tar.gz',
+                        instance_count=2,
+                        instance_type='ml.c4.2xlarge',
+                        transformers_version='4.6.1',
+                        pytorch_version='1.7.1',
+                        model_server_workers=None,
+                        tags=None,
+                        endpoint_name=None
+                    )
+
+        assert result.exit_code == 0
+
+    def test_lightning_deploy_hugging_face_with_hub(self):
+        extra_args = """
+                {
+                    "transformers_version": "4.6.1",
+                    "pytorch_version": "1.7.1",
+                    "hub": {
+                        "HF_MODEL_ID":"gpt2",
+                        "HF_TASK":"text-generation"
+                    }
+                }
+                """
+
+        runner = CliRunner()
+
+        with patch(
+                'sagify.commands.initialize._get_local_aws_profiles',
+                return_value=['default', 'sagify']
+        ):
+            with patch(
+                    'sagify.sagemaker.sagemaker.SageMakerClient'
+            ) as mocked_sage_maker_client:
+                instance = mocked_sage_maker_client.return_value
+                with runner.isolated_filesystem():
+                    with open('extra_config_file.json', 'w') as f:
+                        f.write(extra_args)
+
+                    result = runner.invoke(
+                        cli=cli,
+                        args=[
+                            'cloud', 'lightning-deploy',
+                            '--framework', 'huggingface',
+                            '-n', '2',
+                            '-e', 'ml.c4.2xlarge',
+                            '--extra-config-file', 'extra_config_file.json',
+                            '--aws-region', 'us-east-1',
+                            '--aws-profile', 'sagify'
+                        ]
+                    )
+
+                    assert instance.deploy_hugging_face.call_count == 1
+                    instance.deploy_hugging_face.assert_called_with(
+                        s3_model_location=None,
+                        instance_count=2,
+                        instance_type='ml.c4.2xlarge',
+                        transformers_version='4.6.1',
+                        pytorch_version='1.7.1',
+                        hub={
+                            'HF_MODEL_ID': 'gpt2',
+                            'HF_TASK': 'text-generation'
+                        },
+                        model_server_workers=None,
+                        tags=None,
+                        endpoint_name=None
+                    )
+
+        assert result.exit_code == 0
+
+    def test_lightning_deploy_sklearn_happy_case(self):
+        extra_args = """
+                {
+                    "framework_version": "0.23-1"
+                }
+                """
+
+        runner = CliRunner()
+
+        with patch(
+                'sagify.commands.initialize._get_local_aws_profiles',
+                return_value=['default', 'sagify']
+        ):
+            with patch(
+                    'sagify.sagemaker.sagemaker.SageMakerClient'
+            ) as mocked_sage_maker_client:
+                instance = mocked_sage_maker_client.return_value
+                with runner.isolated_filesystem():
+                    with open('extra_config_file.json', 'w') as f:
+                        f.write(extra_args)
+
+                    result = runner.invoke(
+                        cli=cli,
+                        args=[
+                            'cloud', 'lightning-deploy',
+                            '--framework', 'sklearn',
+                            '-m', 's3://bucket/model/location/model.tar.gz',
+                            '-n', '2',
+                            '-e', 'ml.c4.2xlarge',
+                            '--extra-config-file', 'extra_config_file.json',
+                            '--aws-region', 'us-east-1',
+                            '--aws-profile', 'sagify'
+                        ]
+                    )
+
+                    assert instance.deploy_sklearn.call_count == 1
+                    instance.deploy_sklearn.assert_called_with(
+                        s3_model_location='s3://bucket/model/location/model.tar.gz',
+                        instance_count=2,
+                        instance_type='ml.c4.2xlarge',
+                        framework_version='0.23-1',
+                        model_server_workers=None,
+                        tags=None,
+                        endpoint_name=None
+                    )
+
+        assert result.exit_code == 0
+
+    def test_lightning_deploy_xgboost_happy_case(self):
+        extra_args = """
+                {
+                    "framework_version": "0.90-2"
+                }
+                """
+
+        runner = CliRunner()
+
+        with patch(
+                'sagify.commands.initialize._get_local_aws_profiles',
+                return_value=['default', 'sagify']
+        ):
+            with patch(
+                    'sagify.sagemaker.sagemaker.SageMakerClient'
+            ) as mocked_sage_maker_client:
+                instance = mocked_sage_maker_client.return_value
+                with runner.isolated_filesystem():
+                    with open('extra_config_file.json', 'w') as f:
+                        f.write(extra_args)
+
+                    result = runner.invoke(
+                        cli=cli,
+                        args=[
+                            'cloud', 'lightning-deploy',
+                            '--framework', 'xgboost',
+                            '-m', 's3://bucket/model/location/model.tar.gz',
+                            '-n', '2',
+                            '-e', 'ml.c4.2xlarge',
+                            '--extra-config-file', 'extra_config_file.json',
+                            '--aws-region', 'us-east-1',
+                            '--aws-profile', 'sagify'
+                        ]
+                    )
+
+                    assert instance.deploy_xgboost.call_count == 1
+                    instance.deploy_xgboost.assert_called_with(
+                        s3_model_location='s3://bucket/model/location/model.tar.gz',
+                        instance_count=2,
+                        instance_type='ml.c4.2xlarge',
+                        framework_version='0.90-2',
+                        model_server_workers=None,
+                        tags=None,
+                        endpoint_name=None
+                    )
+
+        assert result.exit_code == 0
